@@ -1,23 +1,23 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2019 Emmanuel Pacaud
+ * Copyright © 2009-2025 Emmanuel Pacaud <emmanuel.pacaud@free.fr>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Emmanuel Pacaud <emmanuel@gnome.org>
+ * Author: Emmanuel Pacaud <emmanuel.pacaud@free.fr>
  */
 
 #ifndef ARV_FAKE_CAMERA_H
@@ -73,6 +73,7 @@ ARV_API void			arv_set_fake_camera_genicam_filename (const char *filename);
 #define ARV_FAKE_CAMERA_REGISTER_TRIGGER_MODE		0x300
 #define ARV_FAKE_CAMERA_REGISTER_TRIGGER_SOURCE		0x304
 #define ARV_FAKE_CAMERA_REGISTER_TRIGGER_ACTIVATION	0x308
+#define ARV_FAKE_CAMERA_REGISTER_TRIGGER_SOFTWARE	0x30c
 
 #define ARV_FAKE_CAMERA_REGISTER_ACQUISITION		0x124
 #define ARV_FAKE_CAMERA_REGISTER_EXPOSURE_TIME_US	0x120
@@ -118,8 +119,12 @@ ARV_API void			arv_fake_camera_set_fill_pattern	(ArvFakeCamera *camera,
 									 ArvFakeCameraFillPattern fill_pattern_callback,
 									 void *fill_pattern_data);
 ARV_API void			arv_fake_camera_set_trigger_frequency	(ArvFakeCamera *camera, double frequency);
+ARV_API gboolean		arv_fake_camera_is_in_free_running_mode (ArvFakeCamera *camera);
+ARV_API gboolean		arv_fake_camera_is_in_software_trigger_mode (ArvFakeCamera *camera);
+ARV_API gboolean		arv_fake_camera_check_and_acknowledge_software_trigger (ArvFakeCamera *camera);
 
 ARV_API const char *		arv_fake_camera_get_genicam_xml		(ArvFakeCamera *camera, size_t *size);
+ARV_API const char *            arv_fake_camera_get_genicam_xml_url     (ArvFakeCamera *camera);
 
 G_END_DECLS
 
