@@ -1,23 +1,23 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2019 Emmanuel Pacaud
+ * Copyright © 2009-2025 Emmanuel Pacaud <emmanuel.pacaud@free.fr>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Emmanuel Pacaud <emmanuel@gnome.org>
+ * Author: Emmanuel Pacaud <emmanuel.pacaud@free.fr>
  */
 
 #include <arvgcmaskedintregnode.h>
@@ -146,7 +146,7 @@ arv_gc_masked_int_reg_node_get_min (ArvGcInteger *self, GError **error)
 	if ((endianness == G_BIG_ENDIAN && (msb > lsb)) ||
 	    (endianness != G_BIG_ENDIAN && (lsb > msb))) {
 		g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_INVALID_BIT_RANGE,
-			     "Invalid bit range for node '%s'",
+			     "[%s] Invalid bit range",
 			     arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (self)));
 		return G_MININT64;
 	}
@@ -176,7 +176,7 @@ arv_gc_masked_int_reg_node_get_max (ArvGcInteger *self, GError **error)
 	if ((endianness == G_BIG_ENDIAN && (msb > lsb)) ||
 	    (endianness != G_BIG_ENDIAN && (lsb > msb))) {
 		g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_INVALID_BIT_RANGE,
-			     "Invalid bit range for node '%s'",
+			     "[%s] Invalid bit range",
 			     arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (self)));
 		return G_MAXINT64;
 	}
