@@ -1,23 +1,23 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2019 Emmanuel Pacaud
+ * Copyright © 2009-2025 Emmanuel Pacaud <emmanuel.pacaud@free.fr>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Emmanuel Pacaud <emmanuel@gnome.org>
+ * Author: Emmanuel Pacaud <emmanuel.pacaud@free.fr>
  */
 
 /**
@@ -32,10 +32,11 @@
 #include <arvgcfeaturenode.h>
 #include <arvgcinteger.h>
 #include <arvgcfloat.h>
+#include <arvgcboolean.h>
 #include <arvgcstring.h>
 #include <arvgc.h>
 #include <arvdomtext.h>
-#include <arvmisc.h>
+#include <arvmiscprivate.h>
 #include <arvdebugprivate.h>
 #include <arvenumtypes.h>
 #include <string.h>
@@ -110,6 +111,8 @@ arv_gc_property_node_get_node_name (ArvDomNode *node)
 			return "Constant";
 		case ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE:
 			return "AccessMode";
+		case ARV_GC_PROPERTY_NODE_TYPE_IMPOSED_ACCESS_MODE:
+			return "ImposedAccessMode";
 		case ARV_GC_PROPERTY_NODE_TYPE_CACHABLE:
 			return "Cachable";
 		case ARV_GC_PROPERTY_NODE_TYPE_POLLING_TIME:
@@ -239,8 +242,7 @@ _get_value_data (ArvGcPropertyNode *property_node)
 		     iter = arv_dom_node_get_next_sibling (iter))
 			g_string_append (string, arv_dom_character_data_get_data (ARV_DOM_CHARACTER_DATA (iter)));
 		g_free (priv->value_data);
-		priv->value_data = string->str;
-		g_string_free (string, FALSE);
+		priv->value_data = arv_g_string_free_and_steal(string);
 		priv->value_data_up_to_date = TRUE;
 	}
 
@@ -379,6 +381,8 @@ arv_gc_property_node_get_int64 (ArvGcPropertyNode *node, GError **error)
 		return arv_gc_integer_get_value (ARV_GC_INTEGER (pvalue_node), error);
 	} else if (ARV_IS_GC_FLOAT (pvalue_node)) {
 		return (gint64) arv_gc_float_get_value (ARV_GC_FLOAT (pvalue_node), error);
+	} else if (ARV_IS_GC_BOOLEAN (pvalue_node)) {
+		return arv_gc_boolean_get_value (ARV_GC_BOOLEAN (pvalue_node), error) ? 1 : 0;
 	}
 
 	arv_warning_genicam ("[GcPropertyNode::get_int64] Invalid node '%s'",
@@ -1049,6 +1053,24 @@ arv_gc_property_node_new_streamable (void)
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_STREAMABLE);
 }
 
+ArvGcNode *
+arv_gc_property_node_new_is_deprecated (void)
+{
+	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_IS_DEPRECATED);
+}
+
+ArvGcNode *
+arv_gc_property_node_new_p_alias (void)
+{
+	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_P_ALIAS);
+}
+
+ArvGcNode *
+arv_gc_property_node_new_p_cast_alias (void)
+{
+	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_P_CAST_ALIAS);
+}
+
 static void
 _set_property (GObject * object, guint prop_id,
 	       const GValue * value, GParamSpec * pspec)
