@@ -1,3 +1,5 @@
+/* SPDX-License-Identifier:Unlicense */
+
 #include <glib.h>
 #include <arv.h>
 #include <string.h>
@@ -77,6 +79,7 @@ integer_test (void)
 	GError *error = NULL;
 	gint64 v_int64;
 	const char *v_string;
+        ArvGcAccessMode access_mode;
 
 	device = arv_fake_device_new ("TEST0", &error);
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -88,6 +91,9 @@ integer_test (void)
 	node = arv_gc_get_node (genicam, "RWInteger");
 	g_assert (ARV_IS_GC_INTEGER_NODE (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (v_int64, ==, 1);
 
@@ -103,6 +109,24 @@ integer_test (void)
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "1");
 
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "4", &error);
+        g_assert (error == NULL);
+	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), &error);
+        g_assert (error == NULL);
+	g_assert_cmpint (v_int64, ==, 4);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0xf", &error);
+        g_assert (error == NULL);
+	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), &error);
+        g_assert (error == NULL);
+	g_assert_cmpint (v_int64, ==, 15);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0.4", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node), 2, NULL);
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (v_int64, ==, 2);
@@ -110,6 +134,9 @@ integer_test (void)
 	node = arv_gc_get_node (genicam, "P_RWInteger");
 	g_assert (ARV_IS_GC_INTEGER_NODE (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (v_int64, ==, 2);
 
@@ -273,6 +300,7 @@ boolean_test (void)
 	GError *error = NULL;
 	gboolean v_boolean;
 	const char *v_string;
+        ArvGcAccessMode access_mode;
 
 	device = arv_fake_device_new ("TEST0", &error);
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -284,6 +312,9 @@ boolean_test (void)
 	node = arv_gc_get_node (genicam, "RWBoolean");
 	g_assert (ARV_IS_GC_BOOLEAN (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
 	g_assert_cmpint (v_boolean, ==, TRUE);
 
@@ -297,9 +328,59 @@ boolean_test (void)
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "false");
 
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "True", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, TRUE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "False", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "true", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, TRUE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "false", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "1", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, TRUE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "what", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "2", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
 	node = arv_gc_get_node (genicam, "P_RWBoolean");
 	g_assert (ARV_IS_GC_BOOLEAN (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
 	g_assert_cmpint (v_boolean, ==, TRUE);
 
@@ -323,6 +404,7 @@ float_test (void)
 	GError *error = NULL;
 	double v_double;
 	const char *v_string;
+        ArvGcAccessMode access_mode;
 
 	device = arv_fake_device_new ("TEST0", &error);
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -334,6 +416,9 @@ float_test (void)
 	node = arv_gc_get_node (genicam, "RWFloat");
 	g_assert (ARV_IS_GC_FLOAT_NODE (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), NULL);
 	g_assert_cmpfloat (v_double, ==, 0.1);
 
@@ -349,6 +434,18 @@ float_test (void)
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "0.1");
 
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0.4", &error);
+        g_assert (error == NULL);
+	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), &error);
+        g_assert (error == NULL);
+	g_assert_cmpfloat (v_double, ==, 0.4);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0.4.", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
 	arv_gc_float_set_value (ARV_GC_FLOAT (node), 0.2, NULL);
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), NULL);
 	g_assert_cmpfloat (v_double, ==, 0.2);
@@ -356,6 +453,9 @@ float_test (void)
 	node = arv_gc_get_node (genicam, "P_RWFloat");
 	g_assert (ARV_IS_GC_FLOAT_NODE (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), NULL);
 	g_assert_cmpfloat (v_double, ==, 0.2);
 
@@ -382,6 +482,7 @@ enumeration_test (void)
 	gint64 *values;
 	guint n_values;
 	const char *v_string;
+        ArvGcAccessMode access_mode;
 
 	device = arv_fake_device_new ("TEST0", &error);
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -395,6 +496,9 @@ enumeration_test (void)
 	g_assert (ARV_IS_GC_INTEGER (node));
 	g_assert (ARV_IS_GC_STRING (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_int64 = arv_gc_enumeration_get_int_value (ARV_GC_ENUMERATION (node), NULL);
 	g_assert_cmpint (v_int64, ==, 0);
 
@@ -436,6 +540,7 @@ swiss_knife_test (void)
 	ArvGcNode *node;
 	GError *error = NULL;
 	gint64 value;
+        ArvGcAccessMode access_mode;
 
 	device = arv_fake_device_new ("TEST0", &error);
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -447,6 +552,9 @@ swiss_knife_test (void)
 	node = arv_gc_get_node (genicam, "IntSwissKnifeTest");
 	g_assert (ARV_IS_GC_SWISS_KNIFE (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (value, ==, 0x1234);
 
@@ -486,6 +594,7 @@ converter_test (void)
 	GError *error = NULL;
 	double v_double;
 	gint64 v_int64;
+        ArvGcAccessMode access_mode;
 
 	device = arv_fake_device_new ("TEST0", &error);
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -494,9 +603,18 @@ converter_test (void)
 	genicam = arv_device_get_genicam (device);
 	g_assert (ARV_IS_GC (genicam));
 
+	node = arv_gc_get_node (genicam, "ROConverter");
+	g_assert (ARV_IS_GC_CONVERTER (node));
+
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
 	node = arv_gc_get_node (genicam, "Converter");
 	g_assert (ARV_IS_GC_CONVERTER (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), NULL);
 	g_assert_cmpfloat (v_double, ==, 200.0);
 
@@ -507,6 +625,9 @@ converter_test (void)
 	node = arv_gc_get_node (genicam, "IntConverter");
 	g_assert (ARV_IS_GC_CONVERTER (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (v_int64, ==, 5);
 
@@ -523,9 +644,15 @@ converter_test (void)
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), NULL);
 	g_assert_cmpint (v_double, ==, 5);
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	node = arv_gc_get_node (genicam, "IntConverterTestSubAndConstant");
 	g_assert (ARV_IS_GC_CONVERTER (node));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (v_int64, ==, 10000);
 
@@ -549,6 +676,7 @@ register_test (void)
 	ArvGcNode *node_uc;
 	ArvGcNode *node_f;
 	ArvGcNode *node_str;
+        ArvGcAccessMode access_mode;
 	const char *string;
 	gint64 value;
 	double value_f;
@@ -562,6 +690,12 @@ register_test (void)
 
 	/* 64 bit IntReg */
 
+	node_a = arv_gc_get_node (genicam, "ROIntRegisterA");
+	g_assert (ARV_IS_GC_REGISTER (node_a));
+
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_a));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
 	node_a = arv_gc_get_node (genicam, "IntRegisterA");
 	g_assert (ARV_IS_GC_REGISTER (node_a));
 	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_a), NULL);
@@ -571,12 +705,18 @@ register_test (void)
 	string = arv_gc_integer_get_unit (ARV_GC_INTEGER (node_a));
 	g_assert_cmpstr (string, ==, "Pa");
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_a));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	value = arv_gc_register_get_address (ARV_GC_REGISTER (node_a), NULL);
 	g_assert_cmpint (value, ==, 0x1050);
 
 	node_b = arv_gc_get_node (genicam, "IntRegisterB");
 	g_assert (ARV_IS_GC_REGISTER (node_b));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_b));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	value = arv_gc_register_get_address (ARV_GC_REGISTER (node_b), NULL);
 	g_assert_cmpint (value, ==, 0x20ff);
 
@@ -596,6 +736,9 @@ register_test (void)
 	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_sc), NULL);
 	g_assert_cmpint (value, ==, 1);
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_sc));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	node_uc = arv_gc_get_node (genicam, "IntUnsigned32BitRegisterC");
 	g_assert (ARV_IS_GC_REGISTER (node_uc));
 	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_uc), NULL);
@@ -605,6 +748,9 @@ register_test (void)
 	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_uc), NULL);
 	g_assert_cmpint (value, ==, 1);
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_uc));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node_sc), -1, NULL);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_sc), NULL);
@@ -632,6 +778,9 @@ register_test (void)
 	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_sc), NULL);
 	g_assert_cmpint (value, ==, 1);
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_sc));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	node_uc = arv_gc_get_node (genicam, "IntUnsigned16BitRegisterC");
 	g_assert (ARV_IS_GC_REGISTER (node_uc));
 	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_uc), NULL);
@@ -641,6 +790,9 @@ register_test (void)
 	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_uc), NULL);
 	g_assert_cmpint (value, ==, 1);
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_uc));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node_sc), -1, NULL);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_sc), NULL);
@@ -665,6 +817,9 @@ register_test (void)
 	string = arv_gc_integer_get_unit (ARV_GC_INTEGER (node_sc));
 	g_assert_cmpstr (string, ==, "V");
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_sc));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	node_uc = arv_gc_get_node (genicam, "MaskedIntUnsignedRegisterC");
 	g_assert (ARV_IS_GC_REGISTER (node_uc));
 	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_uc), NULL);
@@ -676,6 +831,9 @@ register_test (void)
 	string = arv_gc_integer_get_unit (ARV_GC_INTEGER (node_uc));
 	g_assert_cmpstr (string, ==, "A");
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_uc));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	/* 4 byte FLoatReg */
 
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node_c), 0x1234567887654321, NULL);
@@ -689,6 +847,9 @@ register_test (void)
 	string = arv_gc_float_get_unit (ARV_GC_FLOAT (node_f));
 	g_assert_cmpstr (string, ==, "mA");
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_f));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	arv_gc_float_set_value (ARV_GC_FLOAT (node_f), 2.0, NULL);
 	value_f = arv_gc_float_get_value (ARV_GC_FLOAT (node_f), NULL);
 	g_assert_cmpfloat (value_f, ==, 2.0);
@@ -710,6 +871,9 @@ register_test (void)
 	string = arv_gc_float_get_unit (ARV_GC_FLOAT (node_f));
 	g_assert_cmpstr (string, ==, "mV");
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_f));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	arv_gc_float_set_value (ARV_GC_FLOAT (node_f), 1.2, NULL);
 	value_f = arv_gc_float_get_value (ARV_GC_FLOAT (node_f), NULL);
 	g_assert_cmpfloat (value_f, ==, 1.2);
@@ -729,6 +893,9 @@ register_test (void)
 	value = arv_gc_string_get_max_length (ARV_GC_STRING (node_str), NULL);
 	g_assert_cmpint (value, ==, 4);
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_str));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	arv_gc_string_set_value (ARV_GC_STRING (node_str), "Toto", NULL);
 	string = arv_gc_string_get_value (ARV_GC_STRING (node_str), NULL);
 	g_assert_cmpstr (string, ==, "Toto");
@@ -752,6 +919,7 @@ string_test (void)
 	ArvGcNode *node_str;
 	gint64 value;
 	const char *str;
+        ArvGcAccessMode access_mode;
 
 	device = arv_fake_device_new ("TEST0", &error);
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -763,6 +931,9 @@ string_test (void)
 	node_str = arv_gc_get_node (genicam, "StringNodeA");
 	g_assert (ARV_IS_GC_STRING (node_str));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_str));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	value = arv_gc_string_get_max_length (ARV_GC_STRING (node_str), &error);
 	g_assert_cmpint (value, ==, 4);
 	g_assert (error == NULL);
@@ -781,6 +952,9 @@ string_test (void)
 	node_str = arv_gc_get_node (genicam, "StringNodeB");
 	g_assert (ARV_IS_GC_STRING (node_str));
 
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node_str));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
 	value = arv_gc_string_get_max_length (ARV_GC_STRING (node_str), &error);
 	g_assert_cmpint (value, ==, G_MAXINT64);
 	g_assert (error == NULL);
@@ -914,18 +1088,19 @@ create_buffer_with_chunk_data (void)
 	ArvChunkInfos *chunk_infos;
 	char *data;
 	size_t size;
-	guint32 *int_value;
+	guint32 int_value;
 	guint8 *boolean_value;
 	guint offset;
-	double float_value;
-	int i;
+	guint64 float_value;
 
 	size = 64 + 8 + 64 + 8 + 1 + 5 * sizeof (ArvChunkInfos);
 
 	buffer = arv_buffer_new (size, NULL);
 	buffer->priv->payload_type = ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA;
+        buffer->priv->has_chunks = TRUE;
+        buffer->priv->received_size = size;
 	buffer->priv->status = ARV_BUFFER_STATUS_SUCCESS;
-	data = (char *) arv_buffer_get_data (buffer, &size);
+	data = (char *) arv_buffer_get_data (buffer, NULL);
 
 	memset ((char *) data, '\0', size);
 
@@ -934,8 +1109,8 @@ create_buffer_with_chunk_data (void)
 	chunk_infos->id = GUINT32_TO_BE (0x12345678);
 	chunk_infos->size = GUINT32_TO_BE (8);
 
-	int_value = (guint32 *) &data[offset - 8];
-	*int_value = GUINT32_TO_BE (0x11223344);
+	int_value = GUINT32_TO_BE (0x11223344);
+	memcpy ((char *) &data[offset - 8], (char *)&int_value, sizeof(int_value));
 
 	offset -= 8 + sizeof (ArvChunkInfos);
 	chunk_infos = (ArvChunkInfos *) &data[offset];
@@ -949,9 +1124,8 @@ create_buffer_with_chunk_data (void)
 	chunk_infos->id = GUINT32_TO_BE (0x12345679);
 	chunk_infos->size = GUINT32_TO_BE (8);
 
-	float_value = 1.1;
-	for (i = 0; i < sizeof (float_value); i++)
-		data[offset - i - 1] = ((char *) &float_value)[i];
+	float_value = GUINT64_TO_BE (0x3FF199999999999A); /* Hexadecimal representation of 1.1 as double */
+	memcpy ((char *) &data[offset - 8], (char *)&float_value, sizeof(float_value));
 
 	offset -= 8 + sizeof (ArvChunkInfos);
 	chunk_infos = (ArvChunkInfos *) &data[offset];
@@ -1099,6 +1273,155 @@ visibility_test (void)
 	g_object_unref (device);
 }
 
+static void
+category_test (void)
+{
+	ArvDevice *device;
+	ArvGc *genicam;
+	ArvGcNode *node;
+	GError *error = NULL;
+        const GSList *features;
+
+	device = arv_fake_device_new ("TEST0", &error);
+	g_assert (ARV_IS_FAKE_DEVICE (device));
+	g_assert (error == NULL);
+
+	genicam = arv_device_get_genicam (device);
+	g_assert (ARV_IS_GC (genicam));
+
+	node = arv_gc_get_node (genicam, "Root");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        g_assert (ARV_IS_GC_CATEGORY (node));
+
+        g_assert_cmpstr (arv_gc_feature_node_get_description (ARV_GC_FEATURE_NODE (node)), ==, "description");
+        g_assert_cmpstr (arv_gc_feature_node_get_tooltip (ARV_GC_FEATURE_NODE (node)), ==, "tooltip");
+        g_assert_cmpstr (arv_gc_feature_node_get_display_name (ARV_GC_FEATURE_NODE (node)), ==, "display_name");
+
+        features = arv_gc_category_get_features (ARV_GC_CATEGORY (node));
+
+        g_assert_cmpint (g_slist_length ((GSList *) features), ==, 8);
+
+	g_object_unref (device);
+}
+
+static void
+lock_test (void)
+{
+	ArvDevice *device;
+	ArvGc *genicam;
+	ArvGcNode *node;
+	ArvGcNode *lock;
+	GError *error = NULL;
+
+	device = arv_fake_device_new ("TEST0", &error);
+	g_assert (ARV_IS_FAKE_DEVICE (device));
+	g_assert (error == NULL);
+
+	genicam = arv_device_get_genicam (device);
+	g_assert (ARV_IS_GC (genicam));
+
+	node = arv_gc_get_node (genicam, "LockedByInteger");
+	g_assert (ARV_IS_GC_INTEGER_NODE (node));
+        lock = arv_gc_get_node (genicam, "IntegerLock");
+	g_assert (ARV_IS_GC_INTEGER (lock));
+
+        g_assert (!arv_gc_feature_node_is_locked (ARV_GC_FEATURE_NODE (node), &error));
+        g_assert (error == NULL);
+
+        arv_gc_integer_set_value (ARV_GC_INTEGER (lock), 10, &error);
+        g_assert (arv_gc_feature_node_is_locked (ARV_GC_FEATURE_NODE (node), &error));
+        g_assert (error == NULL);
+
+	node = arv_gc_get_node (genicam, "LockedByFloat");
+	g_assert (ARV_IS_GC_INTEGER_NODE (node));
+        lock = arv_gc_get_node (genicam, "FloatLock");
+	g_assert (ARV_IS_GC_FLOAT (lock));
+
+        g_assert (!arv_gc_feature_node_is_locked (ARV_GC_FEATURE_NODE (node), &error));
+        g_assert (error == NULL);
+
+        arv_gc_float_set_value (ARV_GC_FLOAT (lock), 10.0, &error);
+        g_assert (arv_gc_feature_node_is_locked (ARV_GC_FEATURE_NODE (node), &error));
+        g_assert (error == NULL);
+
+	node = arv_gc_get_node (genicam, "LockedByBoolean");
+	g_assert (ARV_IS_GC_INTEGER_NODE (node));
+        lock = arv_gc_get_node (genicam, "BooleanLock");
+	g_assert (ARV_IS_GC_BOOLEAN (lock));
+
+        g_assert (!arv_gc_feature_node_is_locked (ARV_GC_FEATURE_NODE (node), &error));
+        g_assert (error == NULL);
+
+        arv_gc_boolean_set_value (ARV_GC_BOOLEAN (lock), TRUE, &error);
+        g_assert (arv_gc_feature_node_is_locked (ARV_GC_FEATURE_NODE (node), &error));
+        g_assert (error == NULL);
+
+	node = arv_gc_get_node (genicam, "NoLock");
+	g_assert (ARV_IS_GC_INTEGER_NODE (node));
+        g_assert (!arv_gc_feature_node_is_locked (ARV_GC_FEATURE_NODE (node), &error));
+
+	g_object_unref (device);
+}
+
+static void
+access_mode_test (void)
+{
+	ArvDevice *device;
+	ArvGc *genicam;
+	ArvGcNode *node;
+        ArvGcAccessMode access_mode;
+	GError *error = NULL;
+
+	device = arv_fake_device_new ("TEST0", &error);
+	g_assert (ARV_IS_FAKE_DEVICE (device));
+	g_assert (error == NULL);
+
+	genicam = arv_device_get_genicam (device);
+	g_assert (ARV_IS_GC (genicam));
+
+	node = arv_gc_get_node (genicam, "RWRegister_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
+	node = arv_gc_get_node (genicam, "RWRegister_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "RORegister_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "RORegister_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "RWStructEntry_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
+	node = arv_gc_get_node (genicam, "RWStructEntry_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "ROStructEntry_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "ROStructEntry_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	g_object_unref (device);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -1122,6 +1445,9 @@ main (int argc, char *argv[])
 	g_test_add_func ("/genicam/chunk-data", chunk_data_test);
 	g_test_add_func ("/genicam/indexed", indexed_test);
 	g_test_add_func ("/genicam/visibility", visibility_test);
+	g_test_add_func ("/genicam/category", category_test);
+	g_test_add_func ("/genicam/lock", lock_test);
+	g_test_add_func ("/genicam/access-mode", access_mode_test);
 
 	result = g_test_run();
 
